aboutsummaryrefslogtreecommitdiffstats
path: root/cmake/modules
diff options
context:
space:
mode:
authorDavid Morsberger <dave@morsberger.com>2016-01-27 20:24:01 -0500
committerGuy Harris <guy@alum.mit.edu>2016-01-28 02:44:14 +0000
commitda5594744ef61d6c123221d4413cb8d5a351b9b6 (patch)
treef833afc309a2f1a126d0a438680fd30dae264088 /cmake/modules
parent1326cbcc4256897ad9f3d3e48842bed506c8d627 (diff)
Get Clang to report errors for unused vs. unknown linker flags
Change-Id: Iabe497d88239c1e15d7ef6d44c6fca79c8be2d1c Reviewed-on: https://code.wireshark.org/review/13569 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'cmake/modules')
-rw-r--r--cmake/modules/CheckCLinkerFlag.cmake4
1 files changed, 2 insertions, 2 deletions
diff --git a/cmake/modules/CheckCLinkerFlag.cmake b/cmake/modules/CheckCLinkerFlag.cmake
index 9a9096b7e1..120471f182 100644
--- a/cmake/modules/CheckCLinkerFlag.cmake
+++ b/cmake/modules/CheckCLinkerFlag.cmake
@@ -44,10 +44,10 @@ MACRO (CHECK_C_LINKER_FLAG _FLAG _RESULT)
elseif(CMAKE_C_COMPILER_ID MATCHES "Clang")
#
# We'll be running the linker through the compiler driver, so
# we may need to pass -Werror=unknown-warning-option to have it
# fail, rather than just complaining and driving on, if it's
# passed a flag it doesn't handle.
- set(CMAKE_REQUIRED_LIBRARIES "-Werror=unknown-warning-option")
+ set(CMAKE_REQUIRED_LIBRARIES "-Werror=unused-command-line-argument")
endif()
set(CMAKE_REQUIRED_LIBRARIES "${CMAKE_REQUIRED_LIBRARIES} ${_FLAG}")
message(status "check linker flag - test linker flags: ${_FLAG}")
@@ -44,10 +44,10 @@ MACRO (CHECK_C_LINKER_FLAG _FLAG _RESULT)
#
# We'll be running the linker through the compiler driver, so
- # we may need to pass -Werror=unknown-warning-option to have it
+ # we may need to pass -Werror=unused-command-line-argument to have it
# fail, rather than just complaining and driving on, if it's
# passed a flag it doesn't handle.